.. image:: https://badge.fury.io/py/pyebus.svg
    :target: https://badge.fury.io/py/pyebus

.. image:: https://img.shields.io/pypi/dm/pyebus.svg?label=pypi%20downloads
   :target: https://pypi.python.org/pypi/pyebus

.. image:: https://travis-ci.org/c0fec0de/pyebus.svg?branch=main
    :target: https://travis-ci.org/c0fec0de/pyebus

.. image:: https://readthedocs.org/projects/pyebus/badge/?version=latest
    :target: https://pyebus.readthedocs.io/en/latest/?badge=latest

.. image:: https://codeclimate.com/github/c0fec0de/pyebus.png
    :target: https://codeclimate.com/github/c0fec0de/pyebus

.. image:: https://img.shields.io/pypi/pyversions/pyebus.svg
   :target: https://pypi.python.org/pypi/pyebus

.. image:: https://img.shields.io/badge/code%20style-pep8-brightgreen.svg
   :target: https://www.python.org/dev/peps/pep-0008/

.. image:: https://img.shields.io/badge/code%20style-pep257-brightgreen.svg
   :target: https://www.python.org/dev/peps/pep-0257/

Pythonic interface to [EBUSD](https://github.com/john30/ebusd).

